@@ -176,7 +176,7 @@ terminal_app_new_profile (TerminalApp *app,
   if (profile == NULL)
     return;
 
-  terminal_profile_edit (profile, transient_parent, "profile-name-entry");
+  terminal_profile_edit (profile, NULL, "profile-name-entry");
 }
 
 void
@@ -387,10 +387,13 @@ terminal_app_init (TerminalApp *app)
   terminal_accels_init (G_APPLICATION (app), settings);
 
 #if 1
+{
   /* Legacy gtkuimanager menu accelerator */
   /* Disallow in-place menu accel changes. Only needed on gtk 3.8,
    * it's unused and ignored from 3.10 onward. */
+  TERMINAL_UTIL_OBJECT_TYPE_UNDEPRECATE_PROPERTY (GTK_TYPE_SETTINGS, "gtk-can-change-accels");
   g_object_set (gtk_settings_get_default (), "gtk-can-change-accels", FALSE, NULL);
+}
 #endif
 }
 
@@ -596,21 +599,21 @@ terminal_app_edit_profile (TerminalApp     *app,
                            GtkWindow       *transient_parent,
                            const char      *widget_name)
 {
-  terminal_profile_edit (profile, transient_parent, widget_name);
+  terminal_profile_edit (profile, NULL, widget_name);
 }
 
 void
 terminal_app_edit_preferences (TerminalApp     *app,
                                GtkWindow       *transient_parent)
 {
-  terminal_prefs_show_preferences (transient_parent, "general");
+  terminal_prefs_show_preferences (NULL, "general");
 }
 
 void
 terminal_app_edit_encodings (TerminalApp     *app,
                              GtkWindow       *transient_parent)
 {
-  terminal_prefs_show_preferences (transient_parent, "encodings");
+  terminal_prefs_show_preferences (NULL, "encodings");
 }
 
 /**
